==> haskell-charset-0.3.7.1-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-charset/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: charset
version: 0.3.7.1
id: charset-0.3.7.1-eb9c9b19f9448bfb51c91765226aa73d
key: chars_0opeI6HOvWU8FUZilER5sS
license: BSD3
copyright: (c) Edward Kmett 2010-2012
maintainer: ekmett@gmail.com
stability: Experimental
homepage: http://github.com/ekmett/charset
synopsis: Fast unicode character sets based on complemented PATRICIA tries
description:
    Fast unicode character sets based on complemented PATRICIA tries
category: Data
author: Edward Kmett
exposed: True
exposed-modules:
    Data.CharSet Data.CharSet.Common Data.CharSet.Posix
    Data.CharSet.Posix.Ascii Data.CharSet.Posix.Unicode
    Data.CharSet.Unicode Data.CharSet.Unicode.Block
    Data.CharSet.Unicode.Category Data.CharSet.ByteSet
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/charset-0.3.7.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/charset-0.3.7.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/charset-0.3.7.1
hs-libraries: HScharset-0.3.7.1-0opeI6HOvWU8FUZilER5sS
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
haddock-interfaces: /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html: /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-charset-0.3.7.1-7-armv7h.pkg.tar.xz: usr/share/haskell/haskell-charset/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: charset
version: 0.3.7.1
id: charset-0.3.7.1-efbce7d7e6d5ad9047eb0bb349210702
key: chars_CrApTgZi146CZyG9qNFKYs
license: BSD3
copyright: (c) Edward Kmett 2010-2012
maintainer: ekmett@gmail.com
stability: Experimental
homepage: http://github.com/ekmett/charset
synopsis: Fast unicode character sets based on complemented PATRICIA tries
description:
    Fast unicode character sets based on complemented PATRICIA tries
category: Data
author: Edward Kmett
exposed: True
exposed-modules:
    Data.CharSet Data.CharSet.Common Data.CharSet.Posix
    Data.CharSet.Posix.Ascii Data.CharSet.Posix.Unicode
    Data.CharSet.Unicode Data.CharSet.Unicode.Block
    Data.CharSet.Unicode.Category Data.CharSet.ByteSet
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/charset-0.3.7.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/charset-0.3.7.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/charset-0.3.7.1
hs-libraries: HScharset-0.3.7.1-CrApTgZi146CZyG9qNFKYs
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
haddock-interfaces: /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html: /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
